(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     60040,       1482]
NotebookOptionsPosition[     54054,       1385]
NotebookOutlinePosition[     54628,       1406]
CellTagsIndexPosition[     54585,       1403]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"873a8a58-df67-4974-b5e9-60484b1bed6b"],

Cell["Chapter 1, Section 1.5, Figure 1.4", "Section",
 CellChangeTimes->{{3.8513411532187567`*^9, 
  3.851341159727931*^9}},ExpressionUUID->"49be1918-f640-405f-a201-\
7dc1e4dfe0a5"],

Cell["\<\
Enter the orbital periods of the five major uranian satellites (Miranda, \
Ariel, Umbriel, Titania and Oberon).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0a01c0af-49b0-4274-a135-4dc2ded25e84"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Uperiod", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "1.413", ",", " ", "2.520", ",", " ", "4.144", ",", " ", "8.706", ",", 
     " ", "13.463"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8906536430056467`*^9, 3.8906536430095778`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"6f78f648-3026-4061-aad6-a68492bc4f2e"],

Cell["Take the logarithm (base 10) of each period.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fae47e72-6434-47a1-ae6d-b717abad913f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LUperiod", " ", "=", " ", 
  RowBox[{"Log", "[", 
   RowBox[{"10", ",", "Uperiod"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.890653661724228*^9, 3.8906536617275867`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"26604943-e239-4335-8cfb-e74bbe472a32"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.1501421618485586`", ",", "0.401400540781544`", ",", 
   "0.6174197467371766`", ",", "0.9398186628213793`", ",", 
   "1.1291418457922853`"}], "}"}]], "Output",
 CellChangeTimes->{3.890653662664057*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"785026ed-eafa-41a8-a696-89480206f4e8"]
}, Open  ]],

Cell[TextData[{
 "Carry out a linear least squares fit to the data using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox["Fit", "Input"],
 " command.  Here ",
 StyleBox["i",
  FontSlant->"Italic"],
 "=1",
 " denotes Miranda, ",
 StyleBox["i",
  FontSlant->"Italic"],
 "=2 is Ariel, ",
 StyleBox["i",
  FontSlant->"Italic"],
 "=3 is Umbriel, ",
 StyleBox["i",
  FontSlant->"Italic"],
 "=4 is Titania and ",
 StyleBox["i",
  FontSlant->"Italic"],
 "=5 is Oberon."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a4e0afca-1df4-4f18-a894-c70cac216d66"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fn", " ", "=", " ", 
  RowBox[{"Fit", "[", 
   RowBox[{"LUperiod", ",", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", "i"}], "}"}], ",", " ", 
    RowBox[{"{", "i", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8906536731487417`*^9, 3.890653673153051*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"fb9ba0a9-6262-468d-89b8-e2922b105114"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "0.10134065538199818`"}], "+", 
  RowBox[{"0.24964174899272892`", " ", "i"}]}]], "Output",
 CellChangeTimes->{3.890653673917416*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"c084bdf9-8bef-4e6c-85c6-874c87127a2e"]
}, Open  ]],

Cell[TextData[{
 "Now calculate values of this function for each value of ",
 StyleBox["i",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1f8d3670-642e-498d-8a6f-8b4f8e4fe2af"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"calc", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{"fn", ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8906536844187593`*^9, 3.890653684422565*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"d10223db-3ac0-4d09-94ad-871c15974bef"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.14830109361073074`", ",", "0.3979428426034597`", ",", 
   "0.6475845915961885`", ",", "0.8972263405889175`", ",", 
   "1.1468680895816463`"}], "}"}]], "Output",
 CellChangeTimes->{3.890653685348526*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"44ce9a28-0e3c-4ba6-85f4-8a5f8fa238e6"]
}, Open  ]],

Cell["\<\
Compare these with the observed values to calculate the root mean square \
deviation for the actual uranian system.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a16898ad-b4a8-4b1a-9592-bba9b5a1d260"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Chi]Uranus", " ", "=", " ", 
  RowBox[{"Sqrt", "[", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"LUperiod", "-", "calc"}], ")"}], "^", "2"}]}], "]"}], "/", 
    "5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.89065369974971*^9, 3.890653699753042*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"11cb0eab-9c97-4fac-8a70-991eb68ce26e"],

Cell[BoxData["0.024712704046093565`"], "Output",
 CellChangeTimes->{3.890653700493287*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"fce67d85-a575-4f04-ae18-b0dc0c33f2e0"]
}, Open  ]],

Cell[TextData[{
 "Now define a function ",
 StyleBox["CalculateChi", "Input"],
 " to find the equivalent value of \[Chi] for any list of five periods given \
in ",
 StyleBox["period", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ac1ce671-6c5a-488d-a941-fa3a08364e46"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CalculateChi", "[", "period_", "]"}], ":=", "\[IndentingNewLine]", 
  
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"fun", ",", " ", "calc", ",", " ", 
      RowBox[{"lper", "=", 
       RowBox[{"Log", "[", 
        RowBox[{"10", ",", "period"}], "]"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"fun", " ", "=", " ", 
      RowBox[{"Fit", "[", 
       RowBox[{"lper", ",", " ", 
        RowBox[{"{", 
         RowBox[{"1", ",", "i"}], "}"}], ",", 
        RowBox[{"{", "i", "}"}]}], "]"}]}], ";", 
     RowBox[{"calc", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{"fun", ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", "5"}], "}"}]}], "]"}]}], ";", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Apply", "[", 
        RowBox[{"Plus", ",", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"lper", "-", "calc"}], ")"}], "^", "2"}]}], "]"}], "/", 
       "5"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.890653711822505*^9, 3.8906537478878527`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"ade37892-eda9-4947-acee-51daa3f2a883"],

Cell["Set the first orbital period to be that of Miranda.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"51a38eda-7bb6-4fa8-a2c2-38d88fab3fdb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"first", " ", "=", " ", 
  RowBox[{"Uperiod", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.890653762837902*^9, 3.890653762841168*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"d0bcaa32-c098-42c8-bb4f-da730fbbce0a"],

Cell[BoxData["1.413`"], "Output",
 CellChangeTimes->{3.890653765901702*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"ae1d64ee-ef03-4f78-9729-7b8cc6d3f78f"]
}, Open  ]],

Cell["\<\
Set a seed for use in the random number generator.  This allows the same \
values to be reproduced.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d87f3d04-8c18-414f-8852-f3053cafce1c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SeedRandom", "[", "257", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8906537775560207`*^9, 3.890653777559394*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"6a03b01f-8313-4363-a847-132093a8b78a"],

Cell[TextData[{
 "Define a function ",
 StyleBox["PeriodGen", "Input"],
 " that will generate a set of five orbital periods using fixed lower and \
upper limits for successive ratios of periods."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5a17bbdd-e794-4826-b9b5-e1730de61b21"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PeriodGen", "[", 
   RowBox[{"lower_", ",", " ", "upper_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"range", " ", "=", " ", 
      RowBox[{"upper", "-", "lower"}]}], "}"}], ",", 
    RowBox[{"NestList", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"lower", "+", 
          RowBox[{
           RowBox[{"Random", "[", "]"}], "*", "range"}]}], ")"}], "*", "#"}], 
       "&"}], ",", " ", "first", ",", " ", "4"}], "]"}]}], "\n", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.890653791954213*^9, 3.8906537991435823`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"de63514d-2d9f-4724-997f-ae2ab9b23ef4"],

Cell[TextData[{
 "Define a function ",
 StyleBox["GenerateChi", "Input"],
 " that will use ",
 StyleBox["CalculateChi", "Input"],
 " to calculate the value of \[Chi] for the random orbital periods produced \
by ",
 StyleBox["PeriodGen", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d748f361-e523-4122-ab3c-94cef4245978"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GenerateChi", "[", 
   RowBox[{"n_", ",", " ", "lower_", ",", " ", "upper_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"CalculateChi", "[", "#", "]"}], "&"}], ",", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"PeriodGen", "[", 
       RowBox[{"lower", ",", "upper"}], "]"}], ",", 
      RowBox[{"{", "n", "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8906538175455914`*^9, 3.890653823016158*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"e439f611-0c0e-4672-860d-4151e4797e18"],

Cell["\<\
For example, calculate five orbital periods, starting with Miranda's period \
and with successive ratios lying between 1.546 and 2.101 ...\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2154b744-d3df-49ec-ae0f-9e2463cacfb1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PeriodGen", "[", 
  RowBox[{"1.546", ",", " ", "2.101"}], "]"}]], "Input",
 CellChangeTimes->{{3.890653836244751*^9, 3.890653836248043*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"8421c1b7-0153-499f-8334-5e774aae3dfb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.413`", ",", "2.4062136092902002`", ",", "4.442276239667992`", ",", 
   "7.018200519961971`", ",", "12.666611585026532`"}], "}"}]], "Output",
 CellChangeTimes->{3.890653837206183*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"822c9a0d-8c6e-4513-8503-2369c4d1d4ad"]
}, Open  ]],

Cell["... and calculate \[Chi] for this set of periods.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"156df362-1a96-4728-801f-0eb8d1ecd607"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CalculateChi", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.890653849380165*^9, 3.890653849383523*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"2416da39-cba3-4bb7-ae3d-7541a383a698"],

Cell[BoxData["0.012780009096217473`"], "Output",
 CellChangeTimes->{3.89065385032913*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"e716ab19-73d3-4067-b61e-c0db6fce97d7"]
}, Open  ]],

Cell[TextData[{
 "As a further example, generate 10 sets of orbital periods with ",
 StyleBox["lower=1.0", "Input"],
 " and ",
 StyleBox["upper=1.2", "Input"],
 ", calculating \[Chi] for each:"
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"45f593f1-4f80-411a-a1a6-22ba352e0dee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GenerateChi", "[", 
  RowBox[{"10", ",", " ", "1.0", ",", " ", "1.2"}], "]"}]], "Input",
 CellChangeTimes->{{3.8906538636741858`*^9, 3.8906538636785316`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"28b5aca7-fb4f-434e-8297-cd43b1095112"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.008477945762576575`", ",", "0.008554761840026577`", ",", 
   "0.004495836150610577`", ",", "0.004698462511671057`", ",", 
   "0.009648573484098852`", ",", "0.022415007856943312`", ",", 
   "0.00915286978871482`", ",", "0.01634140741396921`", ",", 
   "0.012116293273401807`", ",", "0.012123564967191256`"}], "}"}]], "Output",
 CellChangeTimes->{3.890653864525457*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"b5c62336-dfb2-400e-8e2c-14b032901fd7"]
}, Open  ]],

Cell[TextData[{
 "Now calculate the number of sets of five orbital periods out of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "5"], TraditionalForm]],ExpressionUUID->
  "9d82e942-a545-473e-acb2-dada4e71c64a"],
 "with ",
 StyleBox["lower=1.546", "Input"],
 " and ",
 StyleBox["upper=2.101", "Input"],
 " (the observed values for the uranian system) that have \[Chi] \[LessEqual] \
",
 StyleBox["\[Chi]Uranus", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.811161178405555*^9, 3.811161179352476*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"409db2e8-481a-4d00-911e-f7c5cd9eedb2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Chi]smaller", "=", 
  RowBox[{"Length", "[", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"GenerateChi", "[", 
      RowBox[{"100000", ",", " ", "1.546", ",", " ", "2.101"}], "]"}], ",", 
     " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"#", "<=", "\[Chi]Uranus"}], ")"}], "&"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.890653877078301*^9, 3.890653885752207*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"52b65a71-74f9-4216-9b57-cede4d24ab82"],

Cell[BoxData["78741"], "Output",
 CellChangeTimes->{3.890653891205583*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"a31f664a-52d9-4eac-b7f0-a21beabb5ff5"]
}, Open  ]],

Cell["\<\
Hence, an estimate of the probability of generating as good a fit as the \
uranian system by chance is:\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f365b4eb-e93b-4083-9734-10f0089540f7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"probability", "=", 
  RowBox[{"N", "[", 
   RowBox[{"\[Chi]smaller", "/", "100000"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.890653903659431*^9, 3.890653903662685*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"ba497baa-4feb-438b-bd16-b3d191f864ec"],

Cell[BoxData["0.78741`"], "Output",
 CellChangeTimes->{3.890653904281053*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"e4859fe7-c88c-4476-9dcb-45063372acea"]
}, Open  ]],

Cell["This provides the \"+\" point in Fig.1.4.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e35b5381-525c-4905-baeb-341a3e013db2"],

Cell[TextData[{
 "Now define a function, ",
 StyleBox["Pcurve", "Input"],
 ", to calculate the probability, ",
 StyleBox["P",
  FontSlant->"Italic"],
 ", as a function of the upper limit, ",
 StyleBox["U",
  FontSlant->"Italic"],
 ", for a fixed value of the lower limit, ",
 StyleBox["L",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851341416205393*^9, 3.85134148008104*^9}, {
  3.8513418017355547`*^9, 3.85134181028723*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8400fc20-57c3-4826-a4eb-a8cc74eb9c62"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pcurve", "[", 
   RowBox[{"Lvalue_", ",", "npts_", ",", "duv_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Uvalue", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"uv", ",", 
        RowBox[{"{", 
         RowBox[{"uv", ",", "Lvalue", ",", "5", ",", "duv"}], "}"}]}], 
       "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Chivalues", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"GenerateChi", "[", 
           RowBox[{"npts", ",", "Lvalue", ",", "#"}], "]"}], ")"}], "&"}], 
        ",", " ", "Uvalue"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"Uvalue", ",", 
        RowBox[{"N", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"Select", "[", 
              RowBox[{
               RowBox[{"Chivalues", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"#", "<=", "\[Chi]Uranus"}], ")"}], "&"}]}], "]"}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"Length", "[", "Chivalues", "]"}]}], "}"}]}], "]"}], 
          "/", "npts"}], "]"}]}], "}"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellLabel->"In[16]:=",ExpressionUUID->"7f2dcf0c-0995-40e7-b819-0642a71e6d42"],

Cell["\<\
Prepare the point indicating the location on the plot of the actual value of \
the probability for the uranian system (to be shown as a + symbol).\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851341416205393*^9, 3.85134148008104*^9}, {
  3.8513418017355547`*^9, 3.85134181028723*^9}, {3.851411178883958*^9, 
  3.851411260631403*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9ee28aae-b229-4225-bcab-47090137b9c2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"actual", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics", "[", 
     RowBox[{"Text", "[", 
      RowBox[{"\"\<+\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"2.101", ",", "probability"}], "}"}]}], "]"}], "]"}], "]"}]}],
   ";"}]], "Input",
 CellLabel->"In[17]:=",ExpressionUUID->"7dca5249-4454-44b3-b070-79834c3ec8ee"],

Cell["\<\
Now calculate the data points for the probability curves for each value of \
the lower limit (1.0, 1.2, 1.4 and 1.6).  This can take a while!\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851341416205393*^9, 3.85134148008104*^9}, {
  3.8513418017355547`*^9, 3.85134181028723*^9}, {3.851411178883958*^9, 
  3.8514113500607147`*^9}, {3.890654273621253*^9, 3.890654280356929*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6ec50eb2-7eb5-47e3-b1bd-7a08def79e14"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"p10", "=", 
   RowBox[{"Pcurve", "[", 
    RowBox[{"1.0", ",", "100000", ",", "0.1"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p12", "=", 
   RowBox[{"Pcurve", "[", 
    RowBox[{"1.2", ",", "100000", ",", "0.1"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p14", "=", 
   RowBox[{"Pcurve", "[", 
    RowBox[{"1.4", ",", "100000", ",", "0.1"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p16", "=", 
   RowBox[{"Pcurve", "[", 
    RowBox[{"1.6", ",", "100000", ",", "0.1"}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[18]:=",ExpressionUUID->"e74e915c-b9ad-4d1c-b981-8580e2d9cfb0"],

Cell["Display the four resulting plots ...", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851341416205393*^9, 3.85134148008104*^9}, {
  3.8513418017355547`*^9, 3.85134181028723*^9}, {3.851411178883958*^9, 
  3.8514113770602694`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1b88cbfa-26b6-428c-811b-6c6e543fdd47"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p10", ",", "p12", ",", "p14", ",", "p16"}], "}"}], ",", 
   RowBox[{"FrameStyle", "->", 
    RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"FrameLabel", "->", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Upper Limit, \!\(\*StyleBox[\"U\",FontSlant->\"Italic\"]\)\>\"", 
      ",", "\"\<Probability, \
\!\(\*StyleBox[\"P\",FontSlant->\"Italic\"]\)\>\""}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
   RowBox[{"Joined", "->", "True"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1.0", ",", "1.2", ",", "1.4", ",", "1.6"}], "}"}]}], ",", 
   RowBox[{"Frame", "->", "True"}]}], "]"}]], "Input",
 CellLabel->"In[22]:=",ExpressionUUID->"4560bf78-bbdb-444a-8dff-a0a4f7de15b4"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.009166666666666668], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEf7GH0rJkg8BHONwaDz/Zffuz1rf/23v7sGRD4
Yn9109Z9Hhlv7dPA4Jv9/Mn3zPd9ewrV98N+sdyii7JH7kHN+2lvsFudn3vr
NXsTsHm/7Vd+e1lxxuEi1Lw/9q/Dznu+lz4NNe+fvf1Edc/rPseg5jE4zL1+
Q3XV9kNQ9QwOIQw96Rcu7Ieaz+iwy09Zd+r23VD9TA79vQ571sXvgNrH7CCw
/rX4m7atUPNYHFRjjX+mzd4MNY/FYda2+tSlnhuh5rE6vLdwdS/6uR5qHpuD
3tq2I7bT1kHNY3dwO3doXtmP1VDzOBwk1IJZF09aBTWPw8H1w/6pb26sgJrH
6VB+LW/3hZjl9ulg87gcrqQabvy5YxnUPG6HnpZtc7wLl0LN43FYmdW04jfD
Eqh5PA6cxrn/T3kthprH65B6X/Tg/7BFUPP4HLZ2Tv4t27UIah6/g/HD6b8q
gxdCzRNwWLPioAmP/EKofwQc3EOFXe6yL4CaL+BQeuJsAbPdfKh+QYdba37F
5B6dB7VP0EG1lGkWh/Q8qHlCDmZnrf0uTpwDNU/I4ezLTTNu1MyBmifkUBm7
P8E8ZzbUPGGHM9PFE+TnzoKaJ+ywfYuU0PeIWVDzRBzS1ZsXP7k60x4A4qMY
Sw==
         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.009166666666666668], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQbQwGn+0ZwOCD/dkzIPAFzk8Dg29wPoT+Yc9yalnM
w9j39rNmgsBPe4mpVzgzlF7bQ8z7bf+o9G/T3Q1PoOb9sbe3Kn262eY+1Lx/
9pY77y/UuHAdah6Dw3/Fv99KH1yCqmdwYNudeHvRmXNQ8xkdGhVXR9uqn4Tq
Z3KYHHThrWrvUXsTsH3MDkbMUz++Nz4ENY/FwaUtdM/EygNQ81gczt/KFZ/1
eg/UPFYHNUlL7upbO6HmsTnc6heZmCi6HWoeu0Pot1jBP/lboeZxODxSTvJS
ubgZah6HA3tNnYSizSaoeZwObpdvnnygsRFqHpdDruX0R6s2rYeax+3w6lR6
pdydtVDzeBwKznVcuvdgtf05sHk8DoZOFVsKj6yCmsfr0MvN7rSpYSXUPD4H
k13NN2Y6LYeax+9wo7HYbcq3ZVDzBBz+7lnp0bpxqX06WL2AQ/X349VXTy2B
ulfAYc5+zlYOiyXQ+BF0SDQKNdBauRhqn6DDBzGPgD8Si6HmCTlIBd6Srklc
BDVPyOHP7x6gixZBzRNyKHswR3Dp3oVQ84QdZv974951YgHUPGEHTosWLdPq
BVDzRBxeyzBvur57vj0AGpcELQ==
         "]]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Directive[
         PointSize[0.009166666666666668], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQnQYG3+wZwOADlP4B588Eg59wvjEY/LYXXWmwTeDJ
e/szYPDHfvP7rgf12u/sIeb9sy95/3DSY7+XUH0MDuvmTb5nvu+x/VmwegYH
Lx4m7Xax+/azwOYzOuRw/lyQvvkGVD+Tw0wtialXOK9A7WN2MDtr7Xdx4gWo
eSwO7fvVsq84n4Gax+LwRET25FP7E1DzWB1ChV3usischZrH5mA6o+2hctIh
qHnsUPMOQM3jcDjwvF3w0OK9UPM4HJZmq93PKd4NNY/T4d+sNYH8F3dAzeNy
SGDa/u7Zym1Q87gdnnw3+3uzfwvUPB4Hdo5nLz5Wb4aax+PAEDTbYuf9jVDz
eB2SNdRvhXpstE8Hm8fn4KrVo8tiuQFqHr/DPSbOLvnkdVDzBBxS1pfX7wlf
C7VfwMHslaLUXcc1UPMFHEQuuNz48GWVvQlYv6BD2KwpTXn6K6H2CTo4fkw+
E+u9AmqekMPH6ym9VR3LoOYJOZzWXdt2xHYZ1DwhB0/vp285li+FmifsUC4a
VBf0djHUPGGHntsZDPmNS6DmiTi8yNL+Nv3uYnsAIKPyNQ==
         "]]}, {
        Hue[0.37820393249936934`, 0.6, 0.6], 
        Directive[
         PointSize[0.009166666666666668], 
         RGBColor[0.922526, 0.385626, 0.209179], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQPWsmCPy0ZwCDD/YmxiDwG84/ewYE/sD56Wkg8M+e
ZcKtIyf/voeKMzh0nT2+dWHSe6h6Bodn61SfNM97Yw8xn9Fhy+SDgZ9ePYfq
Z3Ioef9w0mO/x1D7mB06dvE7ZAnfh5rH4mCS8WL+g6SbUPNYHFKD133QE78K
NY/VIa6htuTVqYtQ89gc3qn2XrRadQ5qHrvDmS1/tbV9T0HN43Cwtyp9utnm
ONQ8DodGu4nqntePQM3jdOBdlvijY8YhqHlcDq+PBvhtWX0Aah63Q3WaZ8Os
qH1Q83gcTpwtYLaz3wM1D8gH+n7O/p1Q83gddvayfRDz2AE1j8+BaQ+rkIj9
Nqh5/A52SstchPZugZon4FDCvtG49dxme7DyNAEH9vgZPqI9m6DmCzh8WH7M
27xzI1S/oEM+b87UhMINUPsEHc4+mZ2b57Meap6Qw3tmUASthZon5HBg6psb
HEdWQ80Tcng2Lcz5kdxqqHnCDhO5krkd+VZBzRN2WJUQEqS+YCXUPBGHf9sn
yUo3rrAHAHU557A=
         "]]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {1.0000000000000022`, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox[
         "\"Probability, \
\\!\\(\\*StyleBox[\\\"P\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Upper Limit, \
\\!\\(\\*StyleBox[\\\"U\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> Thickness[0.004], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], LabelStyle -> 
     Directive[FontFamily -> "Times", FontSize -> 16], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
       "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
       Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
       True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotRange -> {{1., 5.}, {0., 1.}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
     Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"1.`", "1.2`", "1.4`", "1.6`"}, "PointLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          Directive[FontFamily -> "Times", FontSize -> 16], FontFamily -> 
          "Arial"}, Background -> Automatic, StripOnInput -> False], 
        TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.560181, 0.691569, 0.194885]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.922526, 0.385626, 0.209179]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"Directive", "[", 
               RowBox[{
                 RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                 RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.890654579690159*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"cf197225-0f1f-48a4-bbac-78f338f78907"]
}, Open  ]],

Cell["\<\
... and add the point denoting the actual value for the uranian system to \
produce Fig.1.4.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851341416205393*^9, 3.85134148008104*^9}, {
  3.8513418017355547`*^9, 3.85134181028723*^9}, {3.851411178883958*^9, 
  3.8514113500607147`*^9}, {3.851411385850609*^9, 3.8514114049446173`*^9}, {
  3.851411506100459*^9, 3.851411513992365*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"679445c6-98e4-41f8-8299-62f9ac7d9ae6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", "actual"}], "]"}]], "Input",
 CellLabel->"In[23]:=",ExpressionUUID->"750b9c03-9499-4754-9908-56ab669b8e8f"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.009166666666666668], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEf7GH0rJkg8BHONwaDz/Zffuz1rf/23v7sGRD4
Yn9109Z9Hhlv7dPA4Jv9/Mn3zPd9ewrV98N+sdyii7JH7kHN+2lvsFudn3vr
NXsTsHm/7Vd+e1lxxuEi1Lw/9q/Dznu+lz4NNe+fvf1Edc/rPseg5jE4zL1+
Q3XV9kNQ9QwOIQw96Rcu7Ieaz+iwy09Zd+r23VD9TA79vQ571sXvgNrH7CCw
/rX4m7atUPNYHFRjjX+mzd4MNY/FYda2+tSlnhuh5rE6vLdwdS/6uR5qHpuD
3tq2I7bT1kHNY3dwO3doXtmP1VDzOBwk1IJZF09aBTWPw8H1w/6pb26sgJrH
6VB+LW/3hZjl9ulg87gcrqQabvy5YxnUPG6HnpZtc7wLl0LN43FYmdW04jfD
Eqh5PA6cxrn/T3kthprH65B6X/Tg/7BFUPP4HLZ2Tv4t27UIah6/g/HD6b8q
gxdCzRNwWLPioAmP/EKofwQc3EOFXe6yL4CaL+BQeuJsAbPdfKh+QYdba37F
5B6dB7VP0EG1lGkWh/Q8qHlCDmZnrf0uTpwDNU/I4ezLTTNu1MyBmifkUBm7
P8E8ZzbUPGGHM9PFE+TnzoKaJ+ywfYuU0PeIWVDzRBzS1ZsXP7k60x4A4qMY
Sw==
          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[0.009166666666666668], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQbQwGn+0ZwOCD/dkzIPAFzk8Dg29wPoT+Yc9yalnM
w9j39rNmgsBPe4mpVzgzlF7bQ8z7bf+o9G/T3Q1PoOb9sbe3Kn262eY+1Lx/
9pY77y/UuHAdah6Dw3/Fv99KH1yCqmdwYNudeHvRmXNQ8xkdGhVXR9uqn4Tq
Z3KYHHThrWrvUXsTsH3MDkbMUz++Nz4ENY/FwaUtdM/EygNQ81gczt/KFZ/1
eg/UPFYHNUlL7upbO6HmsTnc6heZmCi6HWoeu0Pot1jBP/lboeZxODxSTvJS
ubgZah6HA3tNnYSizSaoeZwObpdvnnygsRFqHpdDruX0R6s2rYeax+3w6lR6
pdydtVDzeBwKznVcuvdgtf05sHk8DoZOFVsKj6yCmsfr0MvN7rSpYSXUPD4H
k13NN2Y6LYeax+9wo7HYbcq3ZVDzBBz+7lnp0bpxqX06WL2AQ/X349VXTy2B
ulfAYc5+zlYOiyXQ+BF0SDQKNdBauRhqn6DDBzGPgD8Si6HmCTlIBd6Srklc
BDVPyOHP7x6gixZBzRNyKHswR3Dp3oVQ84QdZv974951YgHUPGEHTosWLdPq
BVDzRBxeyzBvur57vj0AGpcELQ==
          "]]}, {
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[0.009166666666666668], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQnQYG3+wZwOADlP4B588Eg59wvjEY/LYXXWmwTeDJ
e/szYPDHfvP7rgf12u/sIeb9sy95/3DSY7+XUH0MDuvmTb5nvu+x/VmwegYH
Lx4m7Xax+/azwOYzOuRw/lyQvvkGVD+Tw0wtialXOK9A7WN2MDtr7Xdx4gWo
eSwO7fvVsq84n4Gax+LwRET25FP7E1DzWB1ChV3usischZrH5mA6o+2hctIh
qHnsUPMOQM3jcDjwvF3w0OK9UPM4HJZmq93PKd4NNY/T4d+sNYH8F3dAzeNy
SGDa/u7Zym1Q87gdnnw3+3uzfwvUPB4Hdo5nLz5Wb4aax+PAEDTbYuf9jVDz
eB2SNdRvhXpstE8Hm8fn4KrVo8tiuQFqHr/DPSbOLvnkdVDzBBxS1pfX7wlf
C7VfwMHslaLUXcc1UPMFHEQuuNz48GWVvQlYv6BD2KwpTXn6K6H2CTo4fkw+
E+u9AmqekMPH6ym9VR3LoOYJOZzWXdt2xHYZ1DwhB0/vp285li+FmifsUC4a
VBf0djHUPGGHntsZDPmNS6DmiTi8yNL+Nv3uYnsAIKPyNQ==
          "]]}, {
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[0.009166666666666668], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQPWsmCPy0ZwCDD/YmxiDwG84/ewYE/sD56Wkg8M+e
ZcKtIyf/voeKMzh0nT2+dWHSe6h6Bodn61SfNM97Yw8xn9Fhy+SDgZ9ePYfq
Z3Ioef9w0mO/x1D7mB06dvE7ZAnfh5rH4mCS8WL+g6SbUPNYHFKD133QE78K
NY/VIa6htuTVqYtQ89gc3qn2XrRadQ5qHrvDmS1/tbV9T0HN43Cwtyp9utnm
ONQ8DodGu4nqntePQM3jdOBdlvijY8YhqHlcDq+PBvhtWX0Aah63Q3WaZ8Os
qH1Q83gcTpwtYLaz3wM1D8gH+n7O/p1Q83gddvayfRDz2AE1j8+BaQ+rkIj9
Nqh5/A52SstchPZugZon4FDCvtG49dxme7DyNAEH9vgZPqI9m6DmCzh8WH7M
27xzI1S/oEM+b87UhMINUPsEHc4+mZ2b57Meap6Qw3tmUASthZon5HBg6psb
HEdWQ80Tcng2Lcz5kdxqqHnCDhO5krkd+VZBzRN2WJUQEqS+YCXUPBGHf9sn
yUo3rrAHAHU557A=
          "]]}}}, {{}, {}}}, 
     InsetBox[
      FormBox["\"+\"", TraditionalForm], {2.101, 0.78741}]}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {1.0000000000000022`, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox[
         "\"Probability, \
\\!\\(\\*StyleBox[\\\"P\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Upper Limit, \
\\!\\(\\*StyleBox[\\\"U\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> Thickness[0.004], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], LabelStyle -> 
     Directive[FontFamily -> "Times", FontSize -> 16], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
       "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
       Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
       True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotRange -> {{1., 5.}, {0., 1.}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
     Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"1.`", "1.2`", "1.4`", "1.6`"}, "PointLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          Directive[FontFamily -> "Times", FontSize -> 16], FontFamily -> 
          "Arial"}, Background -> Automatic, StripOnInput -> False], 
        TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.560181, 0.691569, 0.194885]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.922526, 0.385626, 0.209179]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"Directive", "[", 
               RowBox[{
                 RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                 RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.890654579889428*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"4d40d36f-d487-4583-9b83-3baa7b70e394"]
}, Open  ]]
},
WindowToolbars->"MultipurposeBar",
CellGrouping->Manual,
WindowSize->{926, 639},
WindowMargins->{{38, Automatic}, {Automatic, 44}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"0b31b8c5-f814-4ab1-9177-c972d25e1a62"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"873a8a58-df67-4974-b5e9-60484b1bed6b"],
Cell[948, 30, 181, 3, 67, "Section",ExpressionUUID->"49be1918-f640-405f-a201-7dc1e4dfe0a5"],
Cell[1132, 35, 245, 6, 49, "Text",ExpressionUUID->"0a01c0af-49b0-4274-a135-4dc2ded25e84"],
Cell[1380, 43, 362, 8, 30, "Input",ExpressionUUID->"6f78f648-3026-4061-aad6-a68492bc4f2e"],
Cell[1745, 53, 170, 3, 53, "Text",ExpressionUUID->"fae47e72-6434-47a1-ae6d-b717abad913f"],
Cell[CellGroupData[{
Cell[1940, 60, 273, 5, 30, "Input",ExpressionUUID->"26604943-e239-4335-8cfb-e74bbe472a32"],
Cell[2216, 67, 323, 7, 34, "Output",ExpressionUUID->"785026ed-eafa-41a8-a696-89480206f4e8"]
}, Open  ]],
Cell[2554, 77, 605, 26, 76, "Text",ExpressionUUID->"a4e0afca-1df4-4f18-a894-c70cac216d66"],
Cell[CellGroupData[{
Cell[3184, 107, 363, 8, 30, "Input",ExpressionUUID->"fb9ba0a9-6262-468d-89b8-e2922b105114"],
Cell[3550, 117, 249, 5, 34, "Output",ExpressionUUID->"c084bdf9-8bef-4e6c-85c6-874c87127a2e"]
}, Open  ]],
Cell[3814, 125, 242, 8, 53, "Text",ExpressionUUID->"1f8d3670-642e-498d-8a6f-8b4f8e4fe2af"],
Cell[CellGroupData[{
Cell[4081, 137, 331, 7, 30, "Input",ExpressionUUID->"d10223db-3ac0-4d09-94ad-871c15974bef"],
Cell[4415, 146, 325, 7, 34, "Output",ExpressionUUID->"44ce9a28-0e3c-4ba6-85f4-8a5f8fa238e6"]
}, Open  ]],
Cell[4755, 156, 249, 6, 53, "Text",ExpressionUUID->"a16898ad-b4a8-4b1a-9592-bba9b5a1d260"],
Cell[CellGroupData[{
Cell[5029, 166, 430, 11, 30, "Input",ExpressionUUID->"11cb0eab-9c97-4fac-8a70-991eb68ce26e"],
Cell[5462, 179, 168, 2, 34, "Output",ExpressionUUID->"fce67d85-a575-4f04-ae18-b0dc0c33f2e0"]
}, Open  ]],
Cell[5645, 184, 320, 10, 53, "Text",ExpressionUUID->"ac1ce671-6c5a-488d-a941-fa3a08364e46"],
Cell[5968, 196, 1175, 32, 115, "Input",ExpressionUUID->"ade37892-eda9-4947-acee-51daa3f2a883"],
Cell[7146, 230, 177, 3, 53, "Text",ExpressionUUID->"51a38eda-7bb6-4fa8-a2c2-38d88fab3fdb"],
Cell[CellGroupData[{
Cell[7348, 237, 265, 5, 30, "Input",ExpressionUUID->"d0bcaa32-c098-42c8-bb4f-da730fbbce0a"],
Cell[7616, 244, 153, 2, 34, "Output",ExpressionUUID->"ae1d64ee-ef03-4f78-9729-7b8cc6d3f78f"]
}, Open  ]],
Cell[7784, 249, 233, 6, 53, "Text",ExpressionUUID->"d87f3d04-8c18-414f-8852-f3053cafce1c"],
Cell[8020, 257, 229, 4, 30, "Input",ExpressionUUID->"6a03b01f-8313-4363-a847-132093a8b78a"],
Cell[8252, 263, 317, 8, 76, "Text",ExpressionUUID->"5a17bbdd-e794-4826-b9b5-e1730de61b21"],
Cell[8572, 273, 741, 20, 73, "Input",ExpressionUUID->"de63514d-2d9f-4724-997f-ae2ab9b23ef4"],
Cell[9316, 295, 373, 12, 76, "Text",ExpressionUUID->"d748f361-e523-4122-ab3c-94cef4245978"],
Cell[9692, 309, 600, 15, 52, "Input",ExpressionUUID->"e439f611-0c0e-4672-860d-4151e4797e18"],
Cell[10295, 326, 272, 6, 76, "Text",ExpressionUUID->"2154b744-d3df-49ec-ae0f-9e2463cacfb1"],
Cell[CellGroupData[{
Cell[10592, 336, 243, 4, 30, "Input",ExpressionUUID->"8421c1b7-0153-499f-8334-5e774aae3dfb"],
Cell[10838, 342, 306, 6, 34, "Output",ExpressionUUID->"822c9a0d-8c6e-4513-8503-2369c4d1d4ad"]
}, Open  ]],
Cell[11159, 351, 175, 3, 53, "Text",ExpressionUUID->"156df362-1a96-4728-801f-0eb8d1ecd607"],
Cell[CellGroupData[{
Cell[11359, 358, 210, 3, 30, "Input",ExpressionUUID->"2416da39-cba3-4bb7-ae3d-7541a383a698"],
Cell[11572, 363, 168, 2, 34, "Output",ExpressionUUID->"e716ab19-73d3-4067-b61e-c0db6fce97d7"]
}, Open  ]],
Cell[11755, 368, 315, 9, 53, "Text",ExpressionUUID->"45f593f1-4f80-411a-a1a6-22ba352e0dee"],
Cell[CellGroupData[{
Cell[12095, 381, 261, 4, 30, "Input",ExpressionUUID->"28b5aca7-fb4f-434e-8297-cd43b1095112"],
Cell[12359, 387, 491, 9, 56, "Output",ExpressionUUID->"b5c62336-dfb2-400e-8e2c-14b032901fd7"]
}, Open  ]],
Cell[12865, 399, 620, 18, 76, "Text",ExpressionUUID->"409db2e8-481a-4d00-911e-f7c5cd9eedb2"],
Cell[CellGroupData[{
Cell[13510, 421, 502, 13, 30, "Input",ExpressionUUID->"52b65a71-74f9-4216-9b57-cede4d24ab82"],
Cell[14015, 436, 153, 2, 34, "Output",ExpressionUUID->"a31f664a-52d9-4eac-b7f0-a21beabb5ff5"]
}, Open  ]],
Cell[14183, 441, 237, 6, 53, "Text",ExpressionUUID->"f365b4eb-e93b-4083-9734-10f0089540f7"],
Cell[CellGroupData[{
Cell[14445, 451, 273, 5, 30, "Input",ExpressionUUID->"ba497baa-4feb-438b-bd16-b3d191f864ec"],
Cell[14721, 458, 156, 2, 34, "Output",ExpressionUUID->"e4859fe7-c88c-4476-9dcb-45063372acea"]
}, Open  ]],
Cell[14892, 463, 167, 3, 53, "Text",ExpressionUUID->"e35b5381-525c-4905-baeb-341a3e013db2"],
Cell[15062, 468, 555, 18, 76, "Text",ExpressionUUID->"8400fc20-57c3-4826-a4eb-a8cc74eb9c62"],
Cell[15620, 488, 1580, 44, 136, "Input",ExpressionUUID->"7f2dcf0c-0995-40e7-b819-0642a71e6d42"],
Cell[17203, 534, 444, 9, 76, "Text",ExpressionUUID->"9ee28aae-b229-4225-bcab-47090137b9c2"],
Cell[17650, 545, 363, 10, 30, "Input",ExpressionUUID->"7dca5249-4454-44b3-b070-79834c3ec8ee"],
Cell[18016, 557, 487, 9, 76, "Text",ExpressionUUID->"6ec50eb2-7eb5-47e3-b1bd-7a08def79e14"],
Cell[18506, 568, 681, 20, 94, "Input",ExpressionUUID->"e74e915c-b9ad-4d1c-b981-8580e2d9cfb0"],
Cell[19190, 590, 328, 6, 53, "Text",ExpressionUUID->"1b88cbfa-26b6-428c-811b-6c6e543fdd47"],
Cell[CellGroupData[{
Cell[19543, 600, 1236, 32, 94, "Input",ExpressionUUID->"4560bf78-bbdb-444a-8dff-a0a4f7de15b4"],
Cell[20782, 634, 16227, 362, 261, "Output",ExpressionUUID->"cf197225-0f1f-48a4-bbac-78f338f78907"]
}, Open  ]],
Cell[37024, 999, 489, 10, 53, "Text",ExpressionUUID->"679445c6-98e4-41f8-8299-62f9ac7d9ae6"],
Cell[CellGroupData[{
Cell[37538, 1013, 164, 3, 30, "Input",ExpressionUUID->"750b9c03-9499-4754-9908-56ab669b8e8f"],
Cell[37705, 1018, 16333, 364, 261, "Output",ExpressionUUID->"4d40d36f-d487-4583-9b83-3baa7b70e394"]
}, Open  ]]
}
]
*)

